unofficial mirror of bug-gnu-emacs@gnu.org 
 help / color / mirror / code / Atom feed
* bug#14994: 24.3; gnus-completing-read in smime.el fails to complete
@ 2013-07-31  9:48 Jens Lechtenboerger
  2013-08-01  0:12 ` Katsumi Yamaoka
  0 siblings, 1 reply; 4+ messages in thread
From: Jens Lechtenboerger @ 2013-07-31  9:48 UTC (permalink / raw)
  To: 14994

Hi there,

the calls to gnus-completing-read in smime-sign-buffer and
smime-decrypt-buffer do not provide completion support.

If I change gnus-completing-read-function from
gnus-emacs-completing-read to completing-read, everything works:

(setq gnus-completing-read-function 'completing-read)

A related problem is reported there:
https://bugs.launchpad.net/ubuntu/+source/emacs24/+bug/1096449

Best wishes
Jens





^ permalink raw reply	[flat|nested] 4+ messages in thread

* bug#14994: 24.3; gnus-completing-read in smime.el fails to complete
  2013-07-31  9:48 bug#14994: 24.3; gnus-completing-read in smime.el fails to complete Jens Lechtenboerger
@ 2013-08-01  0:12 ` Katsumi Yamaoka
  2013-08-01  2:30   ` Stefan Monnier
  0 siblings, 1 reply; 4+ messages in thread
From: Katsumi Yamaoka @ 2013-08-01  0:12 UTC (permalink / raw)
  To: Jens Lechtenboerger; +Cc: 14994-done

[-- Attachment #1: Type: text/plain, Size: 591 bytes --]

Jens Lechtenboerger wrote:
> Hi there,

> the calls to gnus-completing-read in smime-sign-buffer and
> smime-decrypt-buffer do not provide completion support.

> If I change gnus-completing-read-function from
> gnus-emacs-completing-read to completing-read, everything works:

> (setq gnus-completing-read-function 'completing-read)

> A related problem is reported there:
> https://bugs.launchpad.net/ubuntu/+source/emacs24/+bug/1096449

> Best wishes
> Jens

This has been fixed at 2013-05-01 (bug#14304), so it will work
properly in the forthcoming Emacs 24.4.  Here's a patch for 24.3:


[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: Type: text/x-patch, Size: 804 bytes --]

--- gnus-util.el~	2013-01-01 20:37:17.000000000 +0000
+++ gnus-util.el	2013-08-01 00:10:19.897216100 +0000
@@ -1531,9 +1531,12 @@
   "Call standard `completing-read-function'."
   (let ((completion-styles gnus-completion-styles))
     (completing-read prompt
-                     ;; Old XEmacs (at least 21.4) expect an alist for
-                     ;; collection.
-                     (mapcar 'list collection)
+                     ;; Old XEmacs (at least 21.4) expect an alist,
+		     ;; in which the car of each element is a string,
+		     ;; for collection.
+                     (mapcar (lambda (elem)
+			       (list (format "%s" (or (car-safe elem) elem))))
+			     collection)
                      nil require-match initial-input history def)))
 
 (autoload 'ido-completing-read "ido")

^ permalink raw reply	[flat|nested] 4+ messages in thread

* bug#14994: 24.3; gnus-completing-read in smime.el fails to complete
  2013-08-01  0:12 ` Katsumi Yamaoka
@ 2013-08-01  2:30   ` Stefan Monnier
  2013-08-01  3:51     ` Katsumi Yamaoka
  0 siblings, 1 reply; 4+ messages in thread
From: Stefan Monnier @ 2013-08-01  2:30 UTC (permalink / raw)
  To: 14994; +Cc: lechten, yamaoka

> +                     ;; Old XEmacs (at least 21.4) expect an alist,
> +		     ;; in which the car of each element is a string,
> +		     ;; for collection.
> +                     (mapcar (lambda (elem)
> +			       (list (format "%s" (or (car-safe elem) elem))))
> +			     collection)
>                       nil require-match initial-input history def)))
 
I recommend you wrap this in an (if (featurep 'xemacs) ...) so as to
avoid using this code when it's not needed.  After all, it looks both
inefficient and hackish.


        Stefan





^ permalink raw reply	[flat|nested] 4+ messages in thread

* bug#14994: 24.3; gnus-completing-read in smime.el fails to complete
  2013-08-01  2:30   ` Stefan Monnier
@ 2013-08-01  3:51     ` Katsumi Yamaoka
  0 siblings, 0 replies; 4+ messages in thread
From: Katsumi Yamaoka @ 2013-08-01  3:51 UTC (permalink / raw)
  To: Stefan Monnier; +Cc: lechten, 14994

Stefan Monnier wrote:
>> +                     ;; Old XEmacs (at least 21.4) expect an alist,
>> +		     ;; in which the car of each element is a string,
>> +		     ;; for collection.
>> +                     (mapcar (lambda (elem)
>> +			       (list (format "%s" (or (car-safe elem) elem))))
>> +			     collection)
>>                       nil require-match initial-input history def)))

> I recommend you wrap this in an (if (featurep 'xemacs) ...) so as to
> avoid using this code when it's not needed.  After all, it looks both
> inefficient and hackish.

Indeed.  I've simply isolated it as an XEmacs stuff.





^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2013-08-01  3:51 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2013-07-31  9:48 bug#14994: 24.3; gnus-completing-read in smime.el fails to complete Jens Lechtenboerger
2013-08-01  0:12 ` Katsumi Yamaoka
2013-08-01  2:30   ` Stefan Monnier
2013-08-01  3:51     ` Katsumi Yamaoka

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).